==> tellico_3.2.3.orig.tar.xz: tellico-3.2.3/src/commands/renamecollection.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_RENAMECOLLECTION_H
#define TELLICO_RENAMECOLLECTION_H

#include "../datavectors.h"

#include <QUndoCommand>

namespace Tellico {
  namespace Command {

/**
@author Robby Stephenson
*/
class RenameCollection : public QUndoCommand {
public:
  RenameCollection(Data::CollPtr coll, const QString& newTitle);

  virtual void redo() Q_DECL_OVERRIDE;
  virtual void undo() Q_DECL_OVERRIDE;

private:
  Data::CollPtr m_coll;
  QString m_oldTitle;
  QString m_newTitle;
};

  } // end namespace
} // end namespace
#endif

==> tellico_4.1.4.orig.tar.xz: tellico-4.1.4/src/commands/renamecollection.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_RENAMECOLLECTION_H
#define TELLICO_RENAMECOLLECTION_H

#include "../datavectors.h"

#include <QUndoCommand>

namespace Tellico {
  namespace Command {

/**
@author Robby Stephenson
*/
class RenameCollection : public QUndoCommand {
public:
  RenameCollection(Data::CollPtr coll, const QString& newTitle);

  virtual void redo() override;
  virtual void undo() override;

private:
  Data::CollPtr m_coll;
  QString m_oldTitle;
  QString m_newTitle;
};

  } // end namespace
} // end namespace
#endif
